summaryrefslogtreecommitdiff
path: root/net/tipc/addr.c
diff options
context:
space:
mode:
authorDavid S. Miller <davem@sunset.davemloft.net>2006-01-18 14:23:54 -0800
committerDavid S. Miller <davem@sunset.davemloft.net>2006-01-18 14:23:54 -0800
commit27a7b0415f6e5c0ffdfb1ba42b9b96ddfbb78b8f (patch)
tree8107ee11c3fe7d3b4be36054af4475326af86d53 /net/tipc/addr.c
parentad12583f46bcb6ce93ccd99fa063c0d701146b2e (diff)
parent4323add67792ced172d0d93b8b2e6187023115f1 (diff)
Merge git://tipc.cslab.ericsson.net/pub/git/tipc
Diffstat (limited to 'net/tipc/addr.c')
-rw-r--r--net/tipc/addr.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/net/tipc/addr.c b/net/tipc/addr.c
index eca22260c98..0be25e175b9 100644
--- a/net/tipc/addr.c
+++ b/net/tipc/addr.c
@@ -47,7 +47,7 @@ u32 tipc_get_addr(void)
}
/**
* addr_domain_valid - validates a network domain address
*
* Accepts <Z.C.N>, <Z.C.0>, <Z.0.0>, and <0.0.0>,
* where Z, C, and N are non-zero and do not exceed the configured limits.
@@ -55,7 +55,7 @@ u32 tipc_get_addr(void)
* Returns 1 if domain address is valid, otherwise 0
*/
-int addr_domain_valid(u32 addr)
+int tipc_addr_domain_valid(u32 addr)
{
u32 n = tipc_node(addr);
u32 c = tipc_cluster(addr);
@@ -79,7 +79,7 @@ int addr_domain_valid(u32 addr)
}
/**
* addr_node_valid - validates a proposed network address for this node
*
* Accepts <Z.C.N>, where Z, C, and N are non-zero and do not exceed
* the configured limits.
@@ -87,8 +87,8 @@ int addr_domain_valid(u32 addr)
* Returns 1 if address can be used, otherwise 0
*/
-int addr_node_valid(u32 addr)
+int tipc_addr_node_valid(u32 addr)
{
- return (addr_domain_valid(addr) && tipc_node(addr));
+ return (tipc_addr_domain_valid(addr) && tipc_node(addr));
}
@@ -47,7 +47,7 @@ u32 tipc_get_addr(void)
}
/**
- * addr_domain_valid - validates a network domain address
+ * tipc_addr_domain_valid - validates a network domain address
*
* Accepts <Z.C.N>, <Z.C.0>, <Z.0.0>, and <0.0.0>,
@@ -79,7 +79,7 @@ int addr_domain_valid(u32 addr)
}
/**
- * addr_node_valid - validates a proposed network address for this node
+ * tipc_addr_node_valid - validates a proposed network address for this node
*
* Accepts <Z.C.N>, where Z, C, and N are non-zero and do not exceed